package org.apidesign.apifest08.currency;

/**
 * Amount is a class reprezenting an amount of many. It consist of
 * whole currency amount and of pence amount. Both items are long values
 * and it's not defined that the 100 pences = 1 amount. It's up to the converter
 * to verify such invariants.
 *
 * @author jindra
 */
public final class Amount {

    private long amount;
    private long pence;

    /**
     * Construct Amount with no pences.
     *
     * @param amount the amount in some currency
     *
     */
    public Amount(long amount) {
        this.amount = amount;
        this.pence = 0;
    }

    /**
     * Construct Amount with the pences.
     *
     * @param amount the amount in some currency
     * @param pence the pence count
     */
    public Amount(long amount, long pence) {
        this.amount = amount;
        this.pence = pence;
    }

    /**
     * @return the amount
     */
    public long getAmount() {
        return amount;
    }

    /**
     * @param amount the amount to set
     */
    public void setAmount(long amount) {
        this.amount = amount;
    }

    /**
     * @return the pence
     */
    public long getPence() {
        return pence;
    }

    /**
     * @param pence the pence to set
     */
    public void setPence(long pence) {
        this.pence = pence;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (!(obj instanceof Amount)) {
            return false;
        }
        Amount other = (Amount) obj;
        return (amount == other.amount) && (pence == other.pence);
    }

    @Override
    public int hashCode() {
        int hash = 7;
        hash = 79 * hash + (int) (this.amount ^ (this.amount >>> 32));
        hash = 79 * hash + (int) (this.pence ^ (this.pence >>> 32));
        return hash;
    }

    @Override
    public String toString() {
        return amount + "." + pence;
    }


}
